@@ -11,4 +11,6 @@ from .tuple import TenantBasedTuple, Tuple, UserBasedTuple
 from .tuple_ids import AchievementId, AchievementPluginTaskId, BucketId, ConnectedSpaceId, DashboardId, DataSourceId, EnumId, \
 	EnumItemId, ExternalWriterId, FactorId, IndicatorId, InspectionId, ObjectiveAnalysisId, PatId, PipelineActionId, \
 	PipelineGraphicId, PipelineId, PipelineStageId, PipelineUnitId, PluginId, ReportFunnelId, ReportId, SpaceId, \
-	SubjectDatasetColumnId, SubjectId, TenantId, TopicId, UserGroupId, UserId, OssCollectorCompetitiveLockId
+	SubjectDatasetColumnId, SubjectId, TenantId, TopicId, UserGroupId, UserId, CompetitiveLockId, ScheduledTaskId, \
+	ChangeRecordId, ChangeJsonId, CollectorModelConfigId, CollectorTableConfigId, \
+	EventTriggerId, ModelTriggerId, TableTriggerId
